==> ktp-text-ui-15.04.2.tar.xz: ktp-text-ui-15.04.2/filters/searchexpansion/ktptextui_message_filter_searchexpansion.desktop.cmake <==
[Desktop Entry]
Name=Web Shortcuts
Name[ast]=Atayos web
Name[bs]=Web prečice
Name[ca]=Dreceres web
Name[ca@valencia]=Dreceres web
Name[cs]=Webové zkratky
Name[da]=Webgenveje
Name[de]=Web-Kürzel
Name[el]=Συντομεύσεις ιστού
Name[en_GB]=Web Shortcuts
Name[es]=Accesos rápidos a la web
Name[et]=Veebikiirkorraldused
Name[fi]=WWW-pikavalinnat
Name[fr]=Raccourcis Web
Name[ga]=Aicearraí Gréasáin
Name[gl]=Atallos web
Name[hu]=Keresőazonosítók
Name[ia]=Vias Breve de web
Name[it]=Scorciatoie web
Name[kk]=Веб қысқартулары
Name[ko]=웹 바로 가기
Name[lt]=Žiniatinklio nuorodos
Name[mr]=वेब शॉर्टकट
Name[nb]=Nettsnarveier
Name[nds]=Söökafkörten
Name[nl]=Websnelkoppelingen
Name[nn]=Vevsnarvegar
Name[pa]=ਵੈੱਬ ਸ਼ਾਰਟਕੱਟ
Name[pl]=Skróty sieciowe
Name[pt]=Atalhos Web
Name[pt_BR]=Atalhos da Internet
Name[ro]=Acceleratori web
Name[ru]=Веб-сокращения
Name[se]=Fierpmádatlávkestagat
Name[sk]=Webové skratky
Name[sl]=Spletne bližnjice
Name[sr]=Веб пречице
Name[sr@ijekavian]=Веб пречице
Name[sr@ijekavianlatin]=Veb prečice
Name[sr@latin]=Veb prečice
Name[sv]=Webbgenvägar
Name[tr]=Web Kısa Yolları
Name[ug]=تور تېزلەتمىسى
Name[uk]=Вебскорочення
Name[wa]=Rascourtis waibe
Name[x-test]=xxWeb Shortcutsxx
Name[zh_CN]=网页快捷方式
Name[zh_TW]=網頁捷徑
Encoding=UTF-8
Type=Service
Comment=Expand a KDE-shortened URI into a URL (i.e. typing wp:KDE will translate to http://en.wikipedia.org/wiki/KDE)
Comment[bs]=Raširi KDE-skraćen URI u URL (tj. kucanje wp:KDE će prevesti http://en.wikipedia.org/wiki/KDE)
Comment[ca]=Expandeix un URI retallat pel KDE en un URL (p. ex. teclejant wp:KDE es traduirà a http://en.wikipedia.org/wiki/KDE)
Comment[ca@valencia]=Expandeix un URI retallat pel KDE en un URL (p. ex. teclejant wp:KDE es traduirà a http://en.wikipedia.org/wiki/KDE)
Comment[cs]=Rozbalí zkratku URI z KDE na URL (např. wp:KDE se přeloží na http://en.wikipedia.org/wiki/KDE)
Comment[da]=Fold en KDE-forkortet URI ud til en URL (dvs. at skrive wp:KDE vil blive til http://en.wikipedia.org/wiki/KDE)
Comment[de]=Erweitert eine KDE-Web-Kürzel URI zu einer Adresse (URL) (d. h. die Eingabe „wp:KDE“ wird zu „http://de.wikipedia.org/wiki/KDE“  erweitert.
Comment[el]=Αναπτύξτε μια KDE συντόμευση ενός URI σε URL (δηλ. αν πληκτρολογήσετε wp:KDE θα μεταφραστεί σε http://en.wikipedia.org/wiki/KDE)
Comment[en_GB]=Expand a KDE-shortened URI into a URL (i.e. typing wp:KDE will translate to http://en.wikipedia.org/wiki/KDE)
Comment[es]=Expande una URI abreviada de KDE en una URL (por ejemplo, escribir wp:KDE se traducirá a http://en.wikipedia.org/wiki/KDE)
Comment[et]=KDE-lühendusega URI laiendamine URL-iks (kui näiteks kirjutada KDE, siis laiendatakse see aadressiks http://en.wikipedia.org/wiki/KDE)
Comment[fi]=Laajentaa KDE-lyhennetyn URI:n URL:ksi eli kirjoitettu wp:KDE muutetaan muotoon http://en.wikipedia.org/wiki/KDE
Comment[fr]=Développe une URI réduite pour KDE dans une URL (c'est-à-dire la saisie de « wp:KDE » sera traduite en « http://en.wikipedia.org/wiki/KDE »)
Comment[gl]=Expande unha URI acurtada por KDE a un URL (i.e. se escribe wp:KDE hase converter en http://en.wikipedia.org/wiki/KDE)
Comment[hu]=A rövidített KDE URI kibővítése URL-lé (azaz a wp:KDE begépelésekor le lesz fordítva erre: http://en.wikipedia.org/wiki/KDE)
Comment[ia]=Expande un URI abbreviate de KDE in un URL (i.e. typar wp:KDE il traducera se mesme in http://en.wikipedia.org/wiki/KDE)
Comment[it]=Espande un URI abbreviato di KDE in un URL (ad es. wp:KDE sarà trasformato in http://it.wikipedia.org/wiki/KDE)
Comment[kk]=KDE-қыөсқарма URI-ды толық URL-ге аудару (мысалы, wp:KDE дегені http://en.wikipedia.org/wiki/KDE болады)
Comment[ko]=KDE에서 사용한 단축 URI를 URL로 확장(예: wp:KDE는 http://ko.wikipedia.org/wiki/KDE로 확장됨)
Comment[lt]=Išplėsti KDE-sutrumpintus URI į URL (pvz. rašant wp:KDE bu pakeista į http://en.wikipedia.org/wiki/KDE)
Comment[nb]=Fold ut en KDE-forkortet URL til en fullstendig URL (f.eks. wp:KDE blir oversatt til http://en.wikipedia/wiki/KDE)
Comment[nds]=En binnen KDE gellen Söökafkörten to en URL utfoolden (a.B. warrt ut „wp:KDE“ de URL „http://de.wikipedia.org/wiki/KDE“)
Comment[nl]=Expandeer een door KDE afgekorte URI in een URL (bijv. typen van wp:KDE wordt vertaald in http://en.wikipedia.org/wiki/KDE)
Comment[pl]=Rozwiń skrócone przez KDE adresy URI do adresów URL (np. po wpisaniu wp:KDE zostanie to przetłumaczone na http://en.wikipedia.org/wiki/KDE)
Comment[pt]=Expandir um URI curto no KDE para um URL (i.e., se escrever wp:KDE, será traduzido para http://en.wikipedia.org/wiki/KDE)
Comment[pt_BR]=Expande uma URI curta (p.ex., se digitar wp:KDE será transformada em http://en.wikipedia.org/wiki/KDE)
Comment[ru]=Разворачивать KDE-сокращение в веб-адрес (например, wp:KDE будет преобразовано в http://en.wikipedia.org/wiki/KDE)
Comment[sk]=Rozvinúť KDE-skrátené URI do a URL (napr. napísanie wp:KDE sa preloží do http://en.wikipedia.org/wiki/KDE)
Comment[sl]=Razširi URI, ki ga je skrajšal KDE, v naslov URL  (npr. če vtipkate wp:KDE bo to postalo http://en.wikipedia.org/wiki/KDE)
Comment[sr]=Проширите КДЕ‑скраћени УРИ у УРЛ (нпр. унос wp:KDE постаје http://en.wikipedia.org/wiki/KDE).
Comment[sr@ijekavian]=Проширите КДЕ‑скраћени УРИ у УРЛ (нпр. унос wp:KDE постаје http://en.wikipedia.org/wiki/KDE).
Comment[sr@ijekavianlatin]=Proširite KDE-skraćeni URI u URL (npr. unos wp:KDE postaje http://en.wikipedia.org/wiki/KDE).
Comment[sr@latin]=Proširite KDE-skraćeni URI u URL (npr. unos wp:KDE postaje http://en.wikipedia.org/wiki/KDE).
Comment[sv]=Expandera webbadress avkortad av KDE (dvs. att skriva wp:KDE översätts till http://en.wikipedia.org/wiki/KDE)
Comment[tr]=KDE kısaltılmış bir URI'i URL'ye genişlet (örn. wp:KDE yazmak bunu http://en.wikipedia.org/wiki/KDE haline getirecektir)
Comment[uk]=Доповнення вебскорочень адрес KDE до повноцінних адрес (тобто текст wp:KDE буде доповнено до http://en.wikipedia.org/wiki/KDE)
Comment[x-test]=xxExpand a KDE-shortened URI into a URL (i.e. typing wp:KDE will translate to http://en.wikipedia.org/wiki/KDE)xx
Comment[zh_CN]=展开 KDE 的短连接为完整链接 (例如输入 wp:KDE 将会转换为 http://en.wikipedia.org/wiki/KDE)
Comment[zh_TW]=展開 KDE 短網址變成實際網址（例：輸入 wp:KDE 會轉變成 http://en.wikipedia.org/wiki/KDE）
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_searchexpansion
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=searchexpansion
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@

==> ktp-text-ui_15.12.3.orig.tar.xz: ktp-text-ui-15.12.3/filters/searchexpansion/ktptextui_message_filter_searchexpansion.desktop.cmake <==
[Desktop Entry]
Name=Web Shortcuts
Name[ar]=اختصارات الوِبّ
Name[ast]=Atayos web
Name[bs]=Web prečice
Name[ca]=Dreceres web
Name[ca@valencia]=Dreceres web
Name[cs]=Webové zkratky
Name[da]=Webgenveje
Name[de]=Web-Kürzel
Name[el]=Συντομεύσεις ιστού
Name[en_GB]=Web Shortcuts
Name[es]=Accesos rápidos a la web
Name[et]=Veebikiirkorraldused
Name[fi]=WWW-pikavalinnat
Name[fr]=Raccourcis Web
Name[ga]=Aicearraí Gréasáin
Name[gl]=Atallos web
Name[hu]=Keresőazonosítók
Name[ia]=Vias Breve de web
Name[it]=Scorciatoie web
Name[kk]=Веб қысқартулары
Name[ko]=웹 바로 가기
Name[lt]=Žiniatinklio nuorodos
Name[mr]=वेब शॉर्टकट
Name[nb]=Nettsnarveier
Name[nds]=Söökafkörten
Name[nl]=Websnelkoppelingen
Name[nn]=Vevsnarvegar
Name[pa]=ਵੈੱਬ ਸ਼ਾਰਟਕੱਟ
Name[pl]=Skróty sieciowe
Name[pt]=Atalhos Web
Name[pt_BR]=Atalhos da Web
Name[ro]=Acceleratori web
Name[ru]=Веб-сокращения
Name[se]=Fierpmádatlávkestagat
Name[sk]=Webové skratky
Name[sl]=Spletne bližnjice
Name[sr]=Веб пречице
Name[sr@ijekavian]=Веб пречице
Name[sr@ijekavianlatin]=Veb prečice
Name[sr@latin]=Veb prečice
Name[sv]=Webbgenvägar
Name[tr]=Web Kısa Yolları
Name[ug]=تور تېزلەتمىسى
Name[uk]=Вебскорочення
Name[wa]=Rascourtis waibe
Name[x-test]=xxWeb Shortcutsxx
Name[zh_CN]=网页快捷方式
Name[zh_TW]=網頁捷徑
Encoding=UTF-8
Type=Service
Comment=Expand a KDE-shortened URI into a URL (i.e. typing wp:KDE will translate to http://en.wikipedia.org/wiki/KDE)
Comment[ar]=وسّع معرّف URI مقصّر لكدي إلى عنوان URL (مثلًا كتابة wp:KDE سيُترجم إلى http://en.wikipedia.org/wiki/KDE)
Comment[bs]=Raširi KDE-skraćen URI u URL (tj. kucanje wp:KDE će prevesti http://en.wikipedia.org/wiki/KDE)
Comment[ca]=Expandeix un URI retallat pel KDE en un URL (p. ex. teclejant wp:KDE es traduirà a http://en.wikipedia.org/wiki/KDE)
Comment[ca@valencia]=Expandeix un URI retallat pel KDE en un URL (p. ex. teclejant wp:KDE es traduirà a http://en.wikipedia.org/wiki/KDE)
Comment[cs]=Rozbalí zkratku URI z KDE na URL (např. wp:KDE se přeloží na http://en.wikipedia.org/wiki/KDE)
Comment[da]=Fold en KDE-forkortet URI ud til en URL (dvs. at skrive wp:KDE vil blive til http://en.wikipedia.org/wiki/KDE)
Comment[de]=Erweitert eine KDE-Web-Kürzel URI zu einer Adresse (URL) (d. h. die Eingabe „wp:KDE“ wird zu „http://de.wikipedia.org/wiki/KDE“  erweitert.
Comment[el]=Αναπτύξτε μια KDE συντόμευση ενός URI σε URL (δηλ. αν πληκτρολογήσετε wp:KDE θα μεταφραστεί σε http://en.wikipedia.org/wiki/KDE)
Comment[en_GB]=Expand a KDE-shortened URI into a URL (i.e. typing wp:KDE will translate to http://en.wikipedia.org/wiki/KDE)
Comment[es]=Expande una URI abreviada de KDE en una URL (por ejemplo, escribir wp:KDE se traducirá a http://en.wikipedia.org/wiki/KDE)
Comment[et]=KDE-lühendusega URI laiendamine URL-iks (kui näiteks kirjutada KDE, siis laiendatakse see aadressiks http://en.wikipedia.org/wiki/KDE)
Comment[fi]=Laajentaa KDE-lyhennetyn URI:n URL:ksi eli kirjoitettu wp:KDE muutetaan muotoon http://en.wikipedia.org/wiki/KDE
Comment[fr]=Développe une URI réduite pour KDE dans une URL (c'est-à-dire la saisie de « wp:KDE » sera traduite en « http://en.wikipedia.org/wiki/KDE »)
Comment[gl]=Expande unha URI acurtada por KDE a un URL (i.e. se escribe wp:KDE hase converter en http://en.wikipedia.org/wiki/KDE)
Comment[hu]=A rövidített KDE URI kibővítése URL-lé (azaz a wp:KDE begépelésekor le lesz fordítva erre: http://en.wikipedia.org/wiki/KDE)
Comment[ia]=Expande un URI abbreviate de KDE in un URL (i.e. typar wp:KDE il traducera se mesme in http://en.wikipedia.org/wiki/KDE)
Comment[it]=Espande un URI abbreviato di KDE in un URL (ad es. wp:KDE sarà trasformato in http://it.wikipedia.org/wiki/KDE)
Comment[kk]=KDE-қыөсқарма URI-ды толық URL-ге аудару (мысалы, wp:KDE дегені http://en.wikipedia.org/wiki/KDE болады)
Comment[ko]=KDE에서 사용한 단축 URI를 URL로 확장(예: wp:KDE는 http://ko.wikipedia.org/wiki/KDE로 확장됨)
Comment[lt]=Išplėsti KDE-sutrumpintus URI į URL (pvz. rašant wp:KDE bu pakeista į http://en.wikipedia.org/wiki/KDE)
Comment[nb]=Fold ut en KDE-forkortet URL til en fullstendig URL (f.eks. wp:KDE blir oversatt til http://en.wikipedia/wiki/KDE)
Comment[nds]=En binnen KDE gellen Söökafkörten to en URL utfoolden (a.B. warrt ut „wp:KDE“ de URL „http://de.wikipedia.org/wiki/KDE“)
Comment[nl]=Expandeer een door KDE afgekorte URI in een URL (bijv. typen van wp:KDE wordt vertaald in http://en.wikipedia.org/wiki/KDE)
Comment[pl]=Rozwiń skrócone przez KDE adresy URI do adresów URL (np. po wpisaniu wp:KDE zostanie to przetłumaczone na http://en.wikipedia.org/wiki/KDE)
Comment[pt]=Expandir um URI curto no KDE para um URL (i.e., se escrever wp:KDE, será traduzido para http://en.wikipedia.org/wiki/KDE)
Comment[pt_BR]=Expande uma URI curta (p.ex., se digitar wp:KDE será transformada em http://en.wikipedia.org/wiki/KDE)
Comment[ru]=Разворачивать KDE-сокращение в веб-адрес (например, wp:KDE будет преобразовано в http://en.wikipedia.org/wiki/KDE)
Comment[sk]=Rozvinúť KDE-skrátené URI do a URL (napr. napísanie wp:KDE sa preloží do http://en.wikipedia.org/wiki/KDE)
Comment[sl]=Razširi URI, ki ga je skrajšal KDE, v naslov URL  (npr. če vtipkate wp:KDE bo to postalo http://en.wikipedia.org/wiki/KDE)
Comment[sr]=Проширите КДЕ‑скраћени УРИ у УРЛ (нпр. унос wp:KDE постаје http://en.wikipedia.org/wiki/KDE).
Comment[sr@ijekavian]=Проширите КДЕ‑скраћени УРИ у УРЛ (нпр. унос wp:KDE постаје http://en.wikipedia.org/wiki/KDE).
Comment[sr@ijekavianlatin]=Proširite KDE-skraćeni URI u URL (npr. unos wp:KDE postaje http://en.wikipedia.org/wiki/KDE).
Comment[sr@latin]=Proširite KDE-skraćeni URI u URL (npr. unos wp:KDE postaje http://en.wikipedia.org/wiki/KDE).
Comment[sv]=Expandera webbadress avkortad av KDE (dvs. att skriva wp:KDE översätts till http://en.wikipedia.org/wiki/KDE)
Comment[tr]=KDE kısaltılmış bir URI'i URL'ye genişlet (örn. wp:KDE yazmak bunu http://en.wikipedia.org/wiki/KDE haline getirecektir)
Comment[uk]=Доповнення вебскорочень адрес KDE до повноцінних адрес (тобто текст wp:KDE буде доповнено до http://en.wikipedia.org/wiki/KDE)
Comment[x-test]=xxExpand a KDE-shortened URI into a URL (i.e. typing wp:KDE will translate to http://en.wikipedia.org/wiki/KDE)xx
Comment[zh_CN]=展开 KDE 的短连接为完整链接 (例如输入 wp:KDE 将会转换为 http://en.wikipedia.org/wiki/KDE)
Comment[zh_TW]=展開 KDE 短網址變成實際網址（例：輸入 wp:KDE 會轉變成 http://en.wikipedia.org/wiki/KDE）
ServiceTypes=KTpTextUi/MessageFilter

X-KDE-Library=ktptextui_message_filter_searchexpansion
X-KDE-PluginInfo-Author=Lasath Fernando
X-KDE-PluginInfo-Email=kde@lasath.org
X-KDE-PluginInfo-Name=searchexpansion
X-KDE-PluginInfo-Version=@KTP_TEXT_UI_VERSION@
X-KDE-PluginInfo-Website=http://community.kde.org/KTp
X-KDE-PluginInfo-License=GPL
X-KDE-PluginInfo-EnabledByDefault=false
X-KTp-PluginInfo-Version=@KTP_MESSAGE_FILTER_FRAMEWORK_VERSION@
